summaryrefslogtreecommitdiff
path: root/lisp/help-macro.el
diff options
context:
space:
mode:
authorMartin Rudalics <rudalics@gmx.at>2012-01-20 09:12:35 +0100
committerMartin Rudalics <rudalics@gmx.at>2012-01-20 09:12:35 +0100
commitdd6e3cdd5aa93d7c5125bad0b22cce71df5f04d0 (patch)
tree42268699115917ec133b1c805bdb32f7a362235f /lisp/help-macro.el
parent0d0deb382bfc139f4c30f1f17ef1ab410ff94836 (diff)
downloademacs-dd6e3cdd5aa93d7c5125bad0b22cce71df5f04d0.tar.gz
In make-help-screen make original minor-mode-map-alist temporarily visible.
* help-macro.el (make-help-screen): Temporarily restore original binding for minor-mode-map-alist (Bug#10454).
Diffstat (limited to 'lisp/help-macro.el')
-rw-r--r--lisp/help-macro.el9
1 files changed, 6 insertions, 3 deletions
diff --git a/lisp/help-macro.el b/lisp/help-macro.el
index 0bd6f3c4798..112c72778bc 100644
--- a/lisp/help-macro.el
+++ b/lisp/help-macro.el
@@ -184,9 +184,12 @@ and then returns."
(when config
(set-window-configuration config)
(setq config nil))
- ;; `defn' must make sure that its frame is
- ;; selected, so we won't iconify it below.
- (call-interactively defn)
+ ;; Temporarily rebind `minor-mode-map-alist'
+ ;; to `new-minor-mode-map-alist' (Bug#10454).
+ (let ((minor-mode-map-alist new-minor-mode-map-alist))
+ ;; `defn' must make sure that its frame is
+ ;; selected, so we won't iconify it below.
+ (call-interactively defn))
(when new-frame
;; Do not iconify the selected frame.
(unless (eq new-frame (selected-frame))